@@ -11,11 +11,11 @@ __license__ = "GPL"
 __version__ = "$Revision: 12897 $"
 
 from interfaces import IEventAnnotation
-from ng.adapter.ianytitle.anytitlesubscriberbase import AnyTitileSubscriberBase
+from ng.adapter.ianytitle.anytitlesubscriberbase import AnyTitleSubscriberBase
 
-class EventAnnotation2TitleSubscriber( AnyTitileSubscriberBase ) :
+class EventAnnotation2TitleSubscriber( AnyTitleSubscriberBase ) :
 
-    order = 3
+    order = 2
 
     @property
     def title(self) :
